@@ -10,20 +10,31 @@ sub scrape {
     my $content = get(__PACKAGE__->url);
     my @parts = split /<font size="2" color="#4c4c4c">/, $content;
     my @result;
+    my $removed = {};
     for my $part (@parts) {
-        next if $part =~ /削除IPアドレス帯域/;
+        my $is_removed;
+        if ( $part =~ /削除IPアドレス帯域/ ) {
+            $is_removed++;
+        }
         while ($part =~ s{([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)(/[0-9]+)}{}) {
-            push @result,
-              {
-                ip         => $1,
-                subnetmask => $2,
-              };
+            if ( $is_removed ) {
+                $removed->{ $1 . "/" . $2 } = 1;
+            } else {
+                push @result,
+                  {
+                    ip         => $1,
+                    subnetmask => $2,
+                  };
+            }
         }
     }
     my $unique_of = {};
     my @ret;
     for my $cidr ( @result ) {
         my $rule = $cidr->{ip} . "/" . $cidr->{subnetmask};
+        if ( $removed->{$rule} ) {
+            next;
+        }
         if ( ! $unique_of->{$rule} ) {
             push @ret, $cidr;
         }
