@@ -11,12 +11,11 @@ sub scrape {
     my $xpath = q{//div[@class='contents']/table[2]/tr[1]/td/table/tr/td/table/tr[count(preceding-sibling::tr)>0]};
     my $scraper = scraper {
         col 2, unicode => [ 'TEXT', sub { s/\s//g } ];
-        process '//td[position()=3]/text()', sjis => [ 'TEXT', sub { s/\s//g; s/ESC/\x{1b}/; s/SI/\x0f/; }, sub { unpack "H*", shift } ];
     };
 
     my @res = ();
+    my $ua = LWP::UserAgent->new(agent => __PACKAGE__);
     for my $url ( @urls ) {
-        my $ua = LWP::UserAgent->new(agent => __PACKAGE__);
         my $res = $ua->get($url);
         $res->is_success or die "cannot get $url";
         my $html = $res->content;
@@ -47,6 +46,10 @@ WWW::MobileCarrierJP::Softbank::PictogramInfo - 絵文字(Softbank)
     use WWW::MobileCarrierJP::Softbank::PictogramInfo;
     WWW::MobileCarrierJP::Softbank::PictogramInfo->scrape();
 
+=head1 INCOMPATIBILITY
+
+From 2010-02-26, Softbank removes sjis pictogram code from web page.
+
 =head1 AUTHOR
 
 Tokuhiro Matsuno < tokuhirom gmail com >
